
From: Jeff Dike <jdike@addtoit.com>

This patch makes some small changes that parallel changes in 2.6.11:
	The csum buffers are now unsigned char.
	Got rid of an unused define from pgtable-2level.h.

Signed-off-by: Jeff Dike <jdike@addtoit.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/um/include/sysdep-x86_64/checksum.h |    6 +--
 25-akpm/arch/um/kernel/checksum.c                |   43 +++++++++--------------
 25-akpm/include/asm-um/pgtable-2level.h          |    1 
 3 files changed, 20 insertions(+), 30 deletions(-)

diff -puN arch/um/include/sysdep-x86_64/checksum.h~uml-2611-updates arch/um/include/sysdep-x86_64/checksum.h
--- 25/arch/um/include/sysdep-x86_64/checksum.h~uml-2611-updates	2005-03-07 22:16:07.000000000 -0800
+++ 25-akpm/arch/um/include/sysdep-x86_64/checksum.h	2005-03-07 22:16:07.000000000 -0800
@@ -9,7 +9,7 @@
 #include "linux/in6.h"
 #include "asm/uaccess.h"
 
-extern unsigned int csum_partial_copy_from(const char *src, char *dst, int len,
+extern unsigned int csum_partial_copy_from(const unsigned char *src, unsigned char *dst, int len,
 					   int sum, int *err_ptr);
 extern unsigned csum_partial(const unsigned char *buff, unsigned len,
                              unsigned sum);
@@ -23,7 +23,7 @@ extern unsigned csum_partial(const unsig
  */
 
 static __inline__
-unsigned int csum_partial_copy_nocheck(const char *src, char *dst,
+unsigned int csum_partial_copy_nocheck(const unsigned char *src, unsigned char *dst,
 				       int len, int sum)
 {
 	memcpy(dst, src, len);
@@ -31,7 +31,7 @@ unsigned int csum_partial_copy_nocheck(c
 }
 
 static __inline__
-unsigned int csum_partial_copy_from_user(const char *src, char *dst,
+unsigned int csum_partial_copy_from_user(const unsigned char *src, unsigned char *dst,
 					 int len, int sum, int *err_ptr)
 {
 	return csum_partial_copy_from(src, dst, len, sum, err_ptr);
diff -puN arch/um/kernel/checksum.c~uml-2611-updates arch/um/kernel/checksum.c
--- 25/arch/um/kernel/checksum.c~uml-2611-updates	2005-03-07 22:16:07.000000000 -0800
+++ 25-akpm/arch/um/kernel/checksum.c	2005-03-07 22:16:07.000000000 -0800
@@ -6,40 +6,31 @@ unsigned int arch_csum_partial(const uns
 
 unsigned int csum_partial(unsigned char *buff, int len, int sum)
 {
-	return arch_csum_partial(buff, len, sum);
+        return arch_csum_partial(buff, len, sum);
 }
 
 EXPORT_SYMBOL(csum_partial);
 
-unsigned int csum_partial_copy_to(const unsigned char *src, char __user *dst,
-				int len, int sum, int *err_ptr)
+unsigned int csum_partial_copy_to(const unsigned char *src,
+                                  unsigned char __user *dst, int len, int sum,
+                                  int *err_ptr)
 {
-	if(copy_to_user(dst, src, len)){
-		*err_ptr = -EFAULT;
-		return(-1);
-	}
+        if(copy_to_user(dst, src, len)){
+                *err_ptr = -EFAULT;
+                return(-1);
+        }
 
-	return(arch_csum_partial(src, len, sum));
+        return(arch_csum_partial(src, len, sum));
 }
 
-unsigned int csum_partial_copy_from(const unsigned char __user *src, char *dst,
-				int len, int sum, int *err_ptr)
+unsigned int csum_partial_copy_from(const unsigned char __user *src,
+                                    unsigned char *dst,	int len, int sum,
+                                    int *err_ptr)
 {
-	if(copy_from_user(dst, src, len)){
-		*err_ptr = -EFAULT;
-		return(-1);
-	}
+        if(copy_from_user(dst, src, len)){
+                *err_ptr = -EFAULT;
+                return(-1);
+        }
 
-	return arch_csum_partial(dst, len, sum);
+        return arch_csum_partial(dst, len, sum);
 }
-
-/*
- * Overrides for Emacs so that we follow Linus's tabbing style.
- * Emacs will notice this stuff at the end of the file and automatically
- * adjust the settings for this buffer only.  This must remain at the end
- * of the file.
- * ---------------------------------------------------------------------------
- * Local variables:
- * c-file-style: "linux"
- * End:
- */
diff -puN include/asm-um/pgtable-2level.h~uml-2611-updates include/asm-um/pgtable-2level.h
--- 25/include/asm-um/pgtable-2level.h~uml-2611-updates	2005-03-07 22:16:07.000000000 -0800
+++ 25-akpm/include/asm-um/pgtable-2level.h	2005-03-07 22:16:07.000000000 -0800
@@ -21,7 +21,6 @@
  * we don't really have any PMD directory physically.
  */
 #define PTRS_PER_PTE	1024
-#define PTRS_PER_PMD	1
 #define USER_PTRS_PER_PGD ((TASK_SIZE + (PGDIR_SIZE - 1)) / PGDIR_SIZE)
 #define PTRS_PER_PGD	1024
 #define FIRST_USER_PGD_NR       0
_
